import ij.IJ;
import ij.ImagePlus;
import ij.ImageStack;
import ij.measure.Calibration;
import ij.plugin.PlugIn;
import ij.process.ImageProcessor;
import ij.gui.Roi;
import java.awt.Rectangle;

/**
 * This ImageJ plugin crops a stack and updates origin to reflect the new
 * position of the upper left corner.
 *
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 19May2008
 */

public class Crop_Update_OriginTP implements PlugIn {
	private ImagePlus imp, impOut;
	private Roi roi;
	private ImageStack stack, stackOut;

	public void run(String arg) {
		arg = arg.toLowerCase().trim();
		if(arg.equals("about"))
			{showAbout(); return;}
		IJ.register(DICOM_RescaleTP.class);	// remember static values
		imp = IJ.getImage();
		Roi roi = imp.getRoi();
		if(roi==null) {
			IJ.error("First draw a rectangular ROI.");
			return;
		}
		if(roi.getType()!=Roi.RECTANGLE) {
			IJ.error("This plugin requires a rectangular ROI");
			return;
		}
		Rectangle bounds = roi.getBounds();
		stack = imp.getStack();
		stackOut = new ImageStack(bounds.width,
							bounds.height, stack.getColorModel());
		for(int i=0; i<stack.getSize(); i++) {
			ImageProcessor ip = stack.getProcessor(i+1);
			ip.setRoi(roi);
			ImageProcessor ipOut = ip.crop();
			stackOut.addSlice(stack.getSliceLabel(i+1), ipOut);
		}
		ImagePlus impOut = new ImagePlus(imp.getTitle()+", cropped",
															stackOut);
		impOut.setCalibration(imp.getCalibration());
		Calibration calOut = impOut.getCalibration();
		calOut.xOrigin -= bounds.x;
		calOut.yOrigin -= bounds.y;
		impOut.setSlice(imp.getCurrentSlice());
		impOut.show();
		return;
	}

	private void showAbout() {
		IJ.showMessage("About Crop_Update_OriginTP",
		"This plugin crops images or stacks and updates the origin\n"+
		"to reflect the new upper left corner.\n"
		);
		return;
	}

}	// end of Crop_Update_OriginTP