import ij.*;
import ij.plugin.filter.PlugInFilter;
import ij.process.*;
import ij.gui.*;
import java.awt.*;

/** This ImageJ plug-in filter changes 4 quadrant 64x64 images into
	a stack of 128x128 images.
	It is used to convert a strange ImageCenter format.
*/

public class FourBy64_ implements PlugInFilter {

	public int setup(String arg, ImagePlus imp) {
		if (arg.equals("about"))
			{showAbout(); return DONE;}
		return DOES_ALL;
	}

	public void run(ImageProcessor ip) {
		ImageStack stack = make4x64Stack(ip, 4, 4);
		new ImagePlus("Stack", stack).show();
		return;
	}

	void showAbout() {
		IJ.showMessage("About FourBy64",
			"This plug-in filter coverts from 4 quadrants of 64x64\n" +
			"images to a 128x128 stack.\n" +
			"It is used to convert a strange Elscint/ImageCenter format.\n"
		);
	}

/** takes w by h images from each of 4 quadrants and makes w*h composite images
       which hold 4 of the original images, one from each quadrant.
       For w=4, h=4, a 512 x 512 image, becomes 16, 128 x 128 images. 
*/	
	public ImageStack make4x64Stack(ImageProcessor ip, int w, int h) {
		int width = ip.getWidth()/(2*w);
		int xinc = ip.getWidth()/2;
		int height = ip.getHeight()/(2*h);
		int yinc = ip.getHeight()/2;
		ImageStack stack = new ImageStack(2*width, 2*height);
		for (int y=0; y<h; y++)
			for (int x=0; x<w; x++) {
				ImagePlus imptemp = NewImage.createByteImage("Temporary",
						2*width,2*height,1,NewImage.FILL_WHITE);
				ImageProcessor iptemp = imptemp.getProcessor();
				for (int y2=0; y2<2; y2++) {
					for (int x2=0; x2<2; x2++) {
						ip.setRoi(x*width+x2*xinc, 
							y*height+y2*yinc, 
							width, height);
						iptemp.insert(ip.crop(), x2*width, y2*height);
					}
				}
				stack.addSlice(null, iptemp);
				/* imptemp.show();
				boolean tf;
				tf =  IJ.showMessageWithCancel("Temporary Image",
					 "x= "+x+", y="+y+", xinc="+xinc);
				if(! tf) return stack;
				*/
			}
		return stack;
	}
}

