import java.awt.image.ColorModel;
import ij.IJ;
import ij.ImagePlus;
import ij.LookUpTable;
import ij.plugin.PlugIn;
import ij.process.ImageProcessor;
import ij.text.TextWindow;

/**
 * This ImageJ plugin gets the LookUp Tables (LUT) and displays the
 * red, green, and blue values in a text window.  The text window may be
 * saved as a file. The text window format is:
 * R	G	B
 * i.e. 3 decimal numbers separated by <tab>.  This format will go into
 * a spreadsheet readily.  Holding <alt> down on launch changes the
 * format to:
 * R, G, B
 * i.e. 3 decimal numbers separated by <comma><space>.
 *
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 24November2007
 */

public class LUT_Values_TP implements PlugIn {

	public void run(String arg) {
		String s;
		if(IJ.altKeyDown())
			s = ", ";
		else
			s = "\t";
		TextWindow tw = null;
		ColorModel cm = IJ.getImage().getProcessor().getColorModel();
		LookUpTable lut = new LookUpTable(cm);
		byte[] red = lut.getReds(), green = lut.getGreens(),
										blue = lut.getBlues();
		for(int i=0; i<red.length; i++) {
			String line;
			line = Integer.toString(0xff&red[i])+s+
					Integer.toString(0xff&green[i])+s+
					Integer.toString(0xff&blue[i]);
			if(i==0)
				tw = new TextWindow("LUT_Values", line, 150, 800);
			else
				tw.append(line);
		}
		return;
	}

}
