import ij.*;
import ij.plugin.*;
import ij.io.OpenDialog;

import nucmed.NucMedOpener;
import nucmed.Interfile;		// used by NucMedOpener; force compilation
import nucmed.KeyValuePairs;	// used by Interile; force compilation

/**	
 * This ImageJ plugin calls NucMedOpener.
 * If the arguement contains "interfile" then it calls openInterfile(),
 *   otherwise it calls open().
 *
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 25February2002
 *
 * @see nucmed.NucMedOpener
 * @see nucmed.interfile
 * @see nucmed.interfileDecoder
 */
public class NucMed_Open implements PlugIn {
	private static final boolean DEBUG = false;

	public void run(String arg) {
		if(arg.equalsIgnoreCase("about"))
			{showAbout(); return;}
		if(DEBUG)
			IJ.debugMode = true;
		NucMedOpener nmo = new NucMedOpener();
		if(arg.toLowerCase().indexOf("interfile") >= 0) {
			OpenDialog od = new OpenDialog("Open...", "");
			String directory = od.getDirectory();
			String name = od.getFileName();
			if (name==null)
				return;
			String path = directory + name;
			IJ.showStatus("Opening: " + path);
			nmo.openInterfile(directory, name).show();
		} else
			nmo.open();
		if(DEBUG)
			IJ.debugMode = false;
		return;
	}

	public void showAbout() {
		IJ.showMessage("About NucMed_Open",
				"NucMed_Open calls NucMedOpenner.\n"+
				"If installed with arguement of 'interfile' then it\n"+
				"will call openInterfile() which only opens interfile\n"+
				"format files.  Otherwise it will call open() which\n"+
				"will try to identify the type and open both interfile\n"+
				"and other files which ImageJ recognizes.");
		return;
	}

}
