import ij.*;
import ij.process.*;
import ij.gui.*;
import java.awt.*;
import ij.plugin.filter.*;
import ij.measure.Calibration;

/**
 * This ImageJ PluginFilter sets the pixel width, height, and depth.
 * 
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 28October2003
 */
public class PixelWHD_calTP implements PlugInFilter {
	ImagePlus imp;

	public int setup(String arg, ImagePlus imp) {
		this.imp = imp;
		return DOES_ALL;
	}

	public void run(ImageProcessor ip) {
		String[] unit = {"current", "cm", "mm", "inch"};
		Calibration cal = imp.getCalibration();
		unit[0] = cal.getUnit();
		GenericDialog gd = new GenericDialog("Pixel size");
		gd.addNumericField("Pixel Width", cal.pixelWidth, 3);
		gd.addNumericField("Pixel Height", cal.pixelHeight, 3);
		gd.addNumericField("Pixel Depth", cal.pixelDepth, 3);
		gd.addChoice("Units", unit, unit[0]);
		gd.showDialog();
		if(gd.wasCanceled()) return;
		cal.pixelWidth = gd.getNextNumber();
		cal.pixelHeight = gd.getNextNumber();
		cal.pixelDepth = gd.getNextNumber();
		int index = gd.getNextChoiceIndex();
		cal.setUnit(unit[index]);
		imp.setCalibration(cal);
		return;
	}

}
