package nucmed;

import java.util.*;

/**
 * KeyValuePairs
 * Creates a dictionary of key-value pairs
 * Used for both the default values and for each group
 * Groups are linked parent-child
 * The child has all the parents values
 *
 * @author J. Anthony Parker, MD PhD <J.A.Parker@IEEE.org>
 * @version 8November2002
 *
 * @see NucMed.Interfile
 */
public class KeyValuePairs {
	private KeyValuePairs parent = null;
	private KeyValuePairs child = null;
	private Properties p;

	private StringBuffer info = new StringBuffer(2048);
	private String[] groupStart = {"static study (each frame)",
				"dynamic study (each frame group)",
				"gated study (each time window)",
				"spect study (general)"};

	// used to make the default
	public KeyValuePairs() {
		p = new Properties();
		return;
	}

	// used to make the first parent
	public KeyValuePairs(Properties defaultKeyValues) {
		p = new Properties(defaultKeyValues);
		return;
	}		

	// used by newGroup() to make a child
	KeyValuePairs(KeyValuePairs parent) {
		p = new Properties(parent.p);
		this.parent = parent;
		return;
	}

	public KeyValuePairs newGroup() {
		saveInfo("end of interfile", "");
		child = new KeyValuePairs(this);
		return child;
	}

	public void savePair(String key, String value) {
		if(value == null || value.equals("") || value.indexOf("<null>") >= 0)
			return;
		// for java >= 1.2 "p.setProperty(key,value);" is prefered, but 
		//   this is compatible with java1.1
		p.put(key,value);
		return;
	}

	public void saveInfo(String key, String value) {
		if(value == null || value.indexOf("<null>") >= 0)
			return;
		info.append(key+" := "+value+"\r\n");	// inferfile prefers \r\n
		return;
	}

	public boolean isKey(String key) {
		if(p.getProperty(key) == null)
			return false;
		else
			return true;
	}

	public String getValue(String key) {
		return p.getProperty(key);
	}

	public int getIntValue(String key, int dflt) {
		String s = p.getProperty(key);
		if(s == null)
			return dflt;
		try {
			return new Integer(s).intValue();
		} catch (NumberFormatException e) {
			return dflt;
		}
	}

	public float getFloatValue(String key, float dflt) {
		String s = p.getProperty(key);
		if(s == null)
			return dflt;
		try {
			return new Float(s).floatValue();
		} catch (NumberFormatException e) {
			return dflt;
		}
	}

	public double getDoubleValue(String key, double dflt) {
		String s = p.getProperty(key);
		if(s == null)
			return dflt;
		try {
			return new Double(s).doubleValue();
		} catch (NumberFormatException e) {
			return dflt;
		}
	}

	public String getInfo() {
		if(parent == null)
			return info.toString();
		else
			return parent.getTrimedInfo()+info.toString();
	}

	// Trim off the group data
	String getTrimedInfo() {
		String s = info.toString();
		if(parent!=null)
			s = parent.getTrimedInfo()+s;
		for(int i=0; i<groupStart.length; i++) {
			int index = s.indexOf(groupStart[i]);
			if(index>0)
				return s.substring(0,index);
		}
		return s;
	}

	public Properties getProperties() {
		return p;
	}

	public KeyValuePairs getChild() {
		return child;
	}

	public String toString() {
		StringBuffer sb = new StringBuffer(2048);
		if(p == null)
			return "";
		Enumeration enum = p.propertyNames();
		while(enum.hasMoreElements()) {
			String s = (String) enum.nextElement();
			sb.append(s+" := "+p.getProperty(s, "Err: No value")+"\n");
		}
		return sb.toString();
	}

}

